Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(949)

Unified Diff: views/views_delegate.h

Issue 7790010: Revert 98679 - Restoring a session should restore window minimization state on Windows (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src/
Patch Set: Created 9 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « views/test/test_views_delegate.cc ('k') | views/widget/native_widget_gtk.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: views/views_delegate.h
===================================================================
--- views/views_delegate.h (revision 98696)
+++ views/views_delegate.h (working copy)
@@ -12,7 +12,6 @@
#endif
#include "ui/base/accessibility/accessibility_types.h"
-#include "ui/base/ui_base_types.h"
#include "views/views_export.h"
namespace gfx {
@@ -47,20 +46,23 @@
// TODO(beng): perhaps this should be a Widget.
virtual View* GetDefaultParentView() = 0;
// Saves the position, size and "show" state for the window with the
// specified name.
virtual void SaveWindowPlacement(const Widget* widget,
const std::wstring& window_name,
const gfx::Rect& bounds,
- ui::WindowShowState show_state) = 0;
+ bool maximized) = 0;
- // Retrieves the saved position and size and "show" state for the window with
- // the specified name.
- virtual bool GetSavedWindowPlacement(
- const std::wstring& window_name,
- gfx::Rect* bounds,
- ui::WindowShowState* show_state) const = 0;
+ // Retrieves the saved position and size for the window with the specified
+ // name.
+ virtual bool GetSavedWindowBounds(const std::wstring& window_name,
+ gfx::Rect* bounds) const = 0;
+ // Retrieves the saved maximized state for the window with the specified
+ // name.
+ virtual bool GetSavedMaximizedState(const std::wstring& window_name,
+ bool* maximized) const = 0;
+
virtual void NotifyAccessibilityEvent(
views::View* view, ui::AccessibilityTypes::Event event_type) = 0;
« no previous file with comments | « views/test/test_views_delegate.cc ('k') | views/widget/native_widget_gtk.h » ('j') | no next file with comments »
@@ -47,20 +46,23 @@
// TODO(beng): perhaps this should be a Widget.
virtual View* GetDefaultParentView() = 0;
- // Saves the position, size and "show" state for the window with the
+ // Saves the position, size and maximized state for the window with the
// specified name.
virtual void SaveWindowPlacement(const Widget* widget,

Powered by Google App Engine
This is Rietveld 408576698